<div class="sidebar-home">
  <div class="sidebar-tree">
    <ul><li class="toctree-l1">
      <a class="reference internal" href="{{ pathto(master_doc) }}">Home - {{ shorttitle }}</a>
    </li></ul>
  </div>
</div>
